"{ Package: 'jv:cface' }"

LibraryDefinition subclass:#jv_cface
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'* Projects & Packages *'
!


!jv_cface class methodsFor:'description'!

mandatoryPreRequisites
    "list packages which are mandatory as a prerequisite.
     This are packages containing superclasses of my classes and classes which
     are extended by myself.
     They are mandatory, because we need these packages as a prerequisite for loading and compiling.
     This method is generated automatically,
     by searching along the inheritance chain of all of my classes."

    ^ #(
        #'stx:goodies/smaCC'    "SmaCC::SmaCCParser - superclass of Cface::CDefinitionParser"
        #'stx:libbasic'    "LibraryDefinition - superclass of jv_cface"
    )
!

preRequisites
    "list all required packages.
     This list can be maintained manually or (better) generated and
     updated by scanning the superclass hierarchies and looking for
     global variable accesses. (the browser has a menu function for that)
     Howevery, often too much is found, and you may want to explicitely
     exclude individual packages in the #excludedFromPrerequisites method."

    ^ #(
        #'stx:goodies/smaCC'    "SmaCC::SmaCCScanner - superclass of Cface::CDefinitionScanner "
        #'stx:libbasic'    "Object - superclass of Cface::CDerivedTypeNode "
        #'stx:libbasic3'    "Change - superclass of extended ClassChange "
    )
!

referencedPreRequisites
    "list packages which are a prerequisite, because they contain
     classes which are referenced by my classes.
     We do not need these packages as a prerequisite for loading or compiling.
     This method is generated automatically,
     by searching all classes (and their packages) which are referenced by my classes."

    ^ #(
        #'stx:libbasic3'    "ChangeSet - referenced by Cface::Generator>>initialize"
    )
!

subProjects
    "list packages which are known as subprojects.
     The generated makefile will enter those and make there as well.
     However: they are not forced to be loaded when a package is loaded;
     for those, redefine requiredPrerequisites."

    ^ #(
    )
! !

!jv_cface class methodsFor:'description - contents'!

classNamesAndAttributes
    "lists the classes which are to be included in the project.
     Each entry in the list may be: a single class-name (symbol),
     or an array-literal consisting of class name and attributes.
     Attributes are: #autoload or #<os> where os is one of win32, unix,..."

    ^ #(
        "<className> or (<className> attributes...) in load order"
        #'Cface::CDefinitionParser'
        #'Cface::CDefinitionScanner'
        #'Cface::CNode'
        #'Cface::CNodeVisitor'
        #'Cface::GeneratorCommand'
        #'Cface::Platform'
        #'Cface::TypeMapping'
        #'jv_cface'
        #'Cface::CDefinitionNode'
        #'Cface::CModifierNode'
        #'Cface::CNoNode'
        #'Cface::CairoMapping'
        #'Cface::GTKMapping'
        #'Cface::Generator'
        #'Cface::Libgit2Mapping'
        #'Cface::SVNMapping'
        #'Cface::SmalltalkX'
        #'Cface::TypeCollector'
        #'Cface::TypeMapper'
        #'Cface::TypeResolver'
        #'Cface::CArgumentNode'
        #'Cface::CConstNode'
        #'Cface::CDefinitionFileNode'
        #'Cface::CEnumValueNode'
        #'Cface::CFunctionNode'
        #'Cface::CLongNode'
        #'Cface::CShortNode'
        #'Cface::CStructFieldNode'
        #'Cface::CTypeNode'
        #'Cface::CUnsignedNode'
        #'Cface::SmalltalkXGenerator'
        #'Cface::CArrayNode'
        #'Cface::CBuiltinNode'
        #'Cface::CDerivedTypeNode'
        #'Cface::CPointerNode'
        #'Cface::CTypedefNode'
        #'Cface::CUserDefinedTypeNode'
        #'Cface::CCharNode'
        #'Cface::CDoubleNode'
        #'Cface::CEnumNode'
        #'Cface::CFloatNode'
        #'Cface::CFunctionTypeNode'
        #'Cface::CIntNode'
        #'Cface::CStructuredNode'
        #'Cface::CVoidNode'
        #'Cface::CWCharNode'
        #'Cface::CStructNode'
        #'Cface::CUnionNode'
    )
!

extensionMethodNames
    "list class/selector pairs of extensions.
     A correponding method with real names must be present in my concrete subclasses"

    ^ #(
        Stream tab4
    )
! !

!jv_cface class methodsFor:'description - project information'!

companyName
    "Return a companyname which will appear in <lib>.rc"

    ^ 'CVUT FEL'

    "Created: / 08-09-2008 / 23:49:09 / Jan Vrany <vranyj1@fel.cvut.cz>"
!

description
    "Return a description string which will appear in vc.def / bc.def"

    ^ 'Cairo graphics binding'

    "Created: / 08-09-2008 / 23:49:09 / Jan Vrany <vranyj1@fel.cvut.cz>"
!

legalCopyright
    "Return a copyright string which will appear in <lib>.rc"

    ^ 'Copyright 2008 Jan Vrany'

    "Created: / 08-09-2008 / 23:49:09 / Jan Vrany <vranyj1@fel.cvut.cz>"
!

productName
    "Return a product name which will appear in <lib>.rc"

    ^ 'CairoGraphics'

    "Created: / 08-09-2008 / 23:49:09 / Jan Vrany <vranyj1@fel.cvut.cz>"
! !

!jv_cface class methodsFor:'description - svn'!

svnRepositoryUrlString
    "Return a SVN repository URL of myself.
     (Generated since 2011-04-08)
    "        

    ^ '$URL$'
!

svnRevisionNr
    "Return a SVN revision number of myself.
     This number is updated after a commit"

    ^ "$SVN-Revision:"'17'"$"
! !

!jv_cface class methodsFor:'documentation'!

version
    ^'$Id$'
!

version_HG
    ^ '$Changeset: <not expanded> $'
!

version_SVN
    ^ '$Id$'
! !

